@@ -1,6 +1,7 @@
 import requests
 from django.conf import settings
 
+from incv_client.cos import COSClient
 from incv_client.tof import TofClient
 
 
@@ -31,3 +32,7 @@ class INCVUnionClient:
     @property
     def tof(self):
         return TofClient(self)
+
+    @property
+    def cos(self):
+        return COSClient(self)
